@@ -12,18 +12,25 @@
 
 import string
 import math
-from datetime import datetime
+from datetime import datetime, timedelta
 from collections import namedtuple
 
 
 RangeCoordinates = namedtuple('RangeCoordinates', 'row column number_of_rows number_of_columns sheet_name')
 
 
-def convert_coordinates_to_a1(row, column, number_of_row=1, number_of_column=1, sheet_name=None):
+def convert_coordinates_to_a1(
+        row,
+        column,
+        number_of_row=1,
+        number_of_column=1,
+        sheet_name=None
+):
     notation = convert_column_to_letter(column) + str(row)
     if number_of_row > 1 or number_of_column > 1:
         last_column_index = column + number_of_column - 1
-        last_row_index = row + number_of_row - 1    # row 3 with 3 rows is from row 3 to row 5 and not 6
+        # row 3 with 3 rows is from row 3 to row 5 and not 6
+        last_row_index = row + number_of_row - 1
         last_cell_range = convert_column_to_letter(last_column_index) + str(last_row_index)
         notation += ":" + last_cell_range
     if sheet_name:
@@ -33,7 +40,9 @@ def convert_coordinates_to_a1(row, column, number_of_row=1, number_of_column=1,
 
 def append_sheet_name(a1_string, sheet_name):
     if sheet_name is None or sheet_name == "":
-        raise ValueError("Specified an invalid sheet name to append. (" + repr(sheet_name) + ")")
+        raise ValueError(
+            "Specified an invalid sheet name to append. (" + repr(sheet_name) + ")"
+        )
     if '!' in a1_string:
         a1_sheet_name, cells_a1_string = a1_string.split('!')
         if sheet_name != a1_sheet_name:
@@ -102,7 +111,9 @@ def convert_letter_to_column(letters_string):
 
 
 def rgb_to_hex(red=0, green=0, blue=0):
-    return "#{0:02x}{1:02x}{2:02x}".format(int(red*255), int(green*255), int(blue*255)).lower()
+    return "#{0:02x}{1:02x}{2:02x}".format(
+        int(red*255), int(green*255), int(blue*255)
+    ).lower()
 
 
 def hex_to_rgb(hex_color):
@@ -110,7 +121,9 @@ def hex_to_rgb(hex_color):
         hex_color = hex_color.replace('#', '')
 
     rgb = tuple(int(hex_color[i:i + 2], 16) for i in (0, 2, 4))
-    return {'red': rgb[0] / 255.0, 'green': rgb[1] / 255.0, 'blue': rgb[2] / 255.0}
+    return {
+        'red': rgb[0] / 255.0, 'green': rgb[1] / 255.0, 'blue': rgb[2] / 255.0
+    }
 
 
 def datetime_to_serial_number(date):
@@ -118,3 +131,10 @@ def datetime_to_serial_number(date):
     time_delta = (date - google_sheets_epoch)
     date_serial_number = float(time_delta.days) + (float(time_delta.seconds) / 86400)
     return date_serial_number
+
+
+def serial_number_to_datetime(date_serial_number):
+    google_sheets_epoch = datetime(1899, 12, 30)
+    day_decimal = float(date_serial_number) - float(int(date_serial_number))
+    seconds_in_last_day = day_decimal * 24 * 3600
+    return google_sheets_epoch + timedelta(days=int(date_serial_number)) + timedelta(seconds=seconds_in_last_day)
